==> design-system-react-0.8.22.tgz: package/components/media-object/__docs__/storybook-stories.jsx <==
import React from 'react';
import { storiesOf } from '@storybook/react';
import IconSettings from '../../icon-settings';

import MediaObject from '../../media-object';
import Icon from '../../icon';

import { MEDIA_OBJECT } from '../../../utilities/constants';

const DemoMediaObject = (props) => <MediaObject {...props} />;
DemoMediaObject.displayName = 'DemoMediaObject';

storiesOf(MEDIA_OBJECT, module)
	.addDecorator((getStory) => (
		<div className="slds-p-around--medium">
			<IconSettings iconPath="/assets/icons">{getStory()}</IconSettings>
		</div>
	))
	.add('Base', () => (
		<DemoMediaObject
			body="Lorem ipsum dolor sit amet, consectetur adipisicing elit. Fugiat minus molestias reprehenderit consequuntur sapiente. Modi veritatis totam accusantium numquam assumenda. Lorem ipsum dolor sit amet, consectetur adipisicing elit. Fugiat minus molestias reprehenderit consequuntur sapiente. Modi veritatis totam accusantium numquam assumenda."
			figure={<Icon category="standard" name="user" size="medium" />}
		/>
	))
	.add('Figure Vertical Center', () => (
		<DemoMediaObject
			body="Lorem ipsum dolor sit amet, consectetur adipisicing elit. Fugiat minus molestias reprehenderit consequuntur sapiente. Modi veritatis totam accusantium numquam assumenda. Lorem ipsum dolor sit amet, consectetur adipisicing elit. Fugiat minus molestias reprehenderit consequuntur sapiente. Modi veritatis totam accusantium numquam assumenda."
			figure={<Icon category="standard" name="user" size="medium" />}
			verticalCenter
		/>
	));

==> design-system-react-0.9.4.tgz: package/components/media-object/__docs__/storybook-stories.jsx <==
import React from 'react';
import { storiesOf } from '@storybook/react';
import IconSettings from '../../icon-settings';

import MediaObject from '../../media-object';
import Icon from '../../icon';

import { MEDIA_OBJECT } from '../../../utilities/constants';

const DemoMediaObject = (props) => <MediaObject {...props} />;
DemoMediaObject.displayName = 'DemoMediaObject';

storiesOf(MEDIA_OBJECT, module)
	.addDecorator((getStory) => (
		<div className="slds-p-around_medium">
			<IconSettings iconPath="/assets/icons">{getStory()}</IconSettings>
		</div>
	))
	.add('Base', () => (
		<DemoMediaObject
			body="Lorem ipsum dolor sit amet, consectetur adipisicing elit. Fugiat minus molestias reprehenderit consequuntur sapiente. Modi veritatis totam accusantium numquam assumenda. Lorem ipsum dolor sit amet, consectetur adipisicing elit. Fugiat minus molestias reprehenderit consequuntur sapiente. Modi veritatis totam accusantium numquam assumenda."
			figure={<Icon category="standard" name="user" size="medium" />}
		/>
	))
	.add('Figure Vertical Center', () => (
		<DemoMediaObject
			body="Lorem ipsum dolor sit amet, consectetur adipisicing elit. Fugiat minus molestias reprehenderit consequuntur sapiente. Modi veritatis totam accusantium numquam assumenda. Lorem ipsum dolor sit amet, consectetur adipisicing elit. Fugiat minus molestias reprehenderit consequuntur sapiente. Modi veritatis totam accusantium numquam assumenda."
			figure={<Icon category="standard" name="user" size="medium" />}
			verticalCenter
		/>
	));
